@@ -8,17 +8,20 @@ from ldb.cli_utils import add_data_obj_params
 if TYPE_CHECKING:
     from argparse import _SubParsersAction
 
+    from ldb.cli import ArgumentParserT
+
 
 def add_command(options: Namespace) -> None:
-    add(
+    result = add(
         Path("."),
         options.paths,
         options.query_args,
     )
+    print(result.summary())
 
 
 def add_parser(
-    subparsers: "_SubParsersAction[ArgumentParser]",
+    subparsers: "_SubParsersAction[ArgumentParserT]",
     parents: Iterable[ArgumentParser],
 ) -> None:
     parser = subparsers.add_parser(
