@@ -7,7 +7,9 @@ from ldb import config
 from ldb.cli_utils import (
     add_data_format_arguments,
     add_param_option,
+    choice_str,
     simple_name_list,
+    ws_path_identifier,
 )
 from ldb.config import ConfigType
 from ldb.core import get_ldb_instance
@@ -18,6 +20,8 @@ from ldb.index.utils import AnnotMergeStrategy
 if TYPE_CHECKING:
     from argparse import _SubParsersAction
 
+    from ldb.cli import ArgumentParserT
+
 
 def index_command(options: Namespace) -> None:
     tags = [t for lst in options.tags for t in lst]
@@ -37,12 +41,14 @@ def index_command(options: Namespace) -> None:
         tags=tags,
         annot_merge_strategy=options.annot_merge_strategy,
         params=dict(options.params),
+        ephemeral_remote=options.ephemeral_remote,
+        workspace_path=options.workspace_path,
     )
     print(result.summary())
 
 
 def add_parser(
-    subparsers: "_SubParsersAction[ArgumentParser]",
+    subparsers: "_SubParsersAction[ArgumentParserT]",
     parents: Iterable[ArgumentParser],
 ) -> None:
     parser = subparsers.add_parser(
@@ -64,18 +70,41 @@ def add_parser(
         action="append",
         help="Comma-separated list of tags to add to indexed data objects",
     )
+    annot_update_choice_str = choice_str([s.value for s in AnnotMergeStrategy])
     parser.add_argument(
         "--annotation-update",
         metavar="<strategy>",
         dest="annot_merge_strategy",
         default=AnnotMergeStrategy.REPLACE,
-        type=AnnotMergeStrategy,
+        choices=[s.value for s in AnnotMergeStrategy],
         help=(
             "Merge strategy for combining a data object's current annotation "
-            "with the one discovered during indexing."
+            "with the one discovered during indexing. "
+            f"Choices: {annot_update_choice_str}"
         ),
     )
     add_param_option(parser)
+    parser.add_argument(
+        "--ephemeral-remote",
+        action="store_true",
+        default=False,
+        help=(
+            "Allow non-storage cloud files to be indexed. They will be "
+            "copied to read-add storage."
+        ),
+    )
+    parser.add_argument(
+        "-a",
+        "--add",
+        metavar="<ws-path>",
+        dest="workspace_path",
+        type=ws_path_identifier,
+        help=(
+            "Add the indexed result to this workspace dataset. Argument must "
+            "be a path prefixed with 'ws:'. Use 'ws:.' for the current "
+            "workspace."
+        ),
+    )
     parser.add_argument(  # type: ignore[attr-defined]
         "paths",
         metavar="<path>",
