@@ -8,6 +8,8 @@ from ldb.ls import ls, print_dataset_listings
 if TYPE_CHECKING:
     from argparse import _SubParsersAction
 
+    from ldb.cli import ArgumentParserT
+
 
 def ls_command(options: Namespace) -> None:
     ldb_dir = get_ldb_instance()
@@ -28,7 +30,7 @@ def ls_command(options: Namespace) -> None:
 
 
 def add_parser(
-    subparsers: "_SubParsersAction[ArgumentParser]",
+    subparsers: "_SubParsersAction[ArgumentParserT]",
     parents: Iterable[ArgumentParser],
 ) -> None:
     parser = subparsers.add_parser(
