@@ -25,7 +25,11 @@ from typing import (
 from funcy.objects import cached_property
 
 from ldb.collections import LDBMappingCache
-from ldb.exceptions import DatasetNotFoundError, LDBException
+from ldb.exceptions import (
+    DataObjectNotFoundError,
+    DatasetNotFoundError,
+    LDBException,
+)
 from ldb.iter_utils import take
 from ldb.op_type import OpType
 from ldb.path import InstanceDir
@@ -38,6 +42,7 @@ from ldb.query.search import (
 )
 from ldb.typing import JSONDecoded, JSONObject
 from ldb.utils import (
+    DATA_OBJ_ID_PREFIX,
     ROOT,
     format_dataset_identifier,
     format_datetime,
@@ -135,6 +140,9 @@ class Dataset:
         created = format_datetime(attr_dict.pop("created"))
         return dict(created=created, **attr_dict)
 
+    def numbered_versions(self) -> Dict[int, str]:
+        return {i: v for i, v in enumerate(self.versions, 1) if v is not None}
+
 
 class ObjectIDMapping(Dict[str, str]):
     pass
@@ -208,6 +216,23 @@ def get_collection_dir_items(
         yield path.parent.name + path.name, annotation_hash_func(path)
 
 
+def ensure_all_collection_dir_keys_contained(
+    collection_dir1: Path,
+    collection_dir2: Path,
+) -> None:
+    keys = {
+        (p1, p2)
+        for p1 in os.listdir(collection_dir2)
+        for p2 in os.listdir(os.path.join(collection_dir2, p1))
+    }
+    for p1 in os.listdir(collection_dir1):
+        for p2 in os.listdir(os.path.join(collection_dir1, p1)):
+            if (p1, p2) not in keys:
+                raise DataObjectNotFoundError(
+                    f"Data object not found: {DATA_OBJ_ID_PREFIX}{p1}{p2}",
+                )
+
+
 def get_collection_size(
     collection_dir: Union[str, Path],
 ) -> int:
@@ -283,6 +308,68 @@ def iter_datasets(ldb_dir: Union[str, Path]) -> Iterator[Dataset]:
         yield Dataset.parse(load_data_file(Path(entry.path)))
 
 
+def check_datasets_for_data_objects(
+    ldb_dir: Path,
+    data_object_hashes: Iterable[str],
+    error: bool = True,
+) -> Iterator[str]:
+    # collect data objects from datasets
+    collection_identifiers = get_all_dataset_version_identifiers(ldb_dir)
+    obj_to_identifiers = defaultdict(list)
+    for collection_id, ds_identifiers in collection_identifiers.items():
+        if ds_identifiers:
+            for data_obj_hash in load_data_file(
+                get_hash_path(
+                    ldb_dir / InstanceDir.COLLECTIONS,
+                    collection_id,
+                ),
+            ):
+                obj_to_identifiers[data_obj_hash].extend(ds_identifiers)
+    for data_obj_hash in data_object_hashes:
+        obj_ds_identifiers = obj_to_identifiers.get(data_obj_hash)
+        if obj_ds_identifiers is not None:
+            if error:
+                ds_ident_str = "\n".join(f"  {i}" for i in obj_ds_identifiers)
+                raise LDBException(
+                    f"Data object id:{data_obj_hash} is contained in saved "
+                    f"datasets:\n{ds_ident_str}",
+                )
+        else:
+            yield data_obj_hash
+
+
+def get_all_dataset_version_identifiers(ldb_dir: Path) -> Dict[str, List[str]]:
+    """
+    Map each dataset version id to all dataset identifiers that point to it.
+
+    This could look something like this:
+        {
+            "0ef...": ["ds:cats.v5"],
+            "38f...": ["ds:cats.v1", ds:cat-images.v3"],
+            "ab3...": [],
+        }
+    """
+    ds_version_dir = os.path.join(ldb_dir, InstanceDir.DATASET_VERSIONS)
+    collection_dir = os.path.join(ldb_dir, InstanceDir.COLLECTIONS)
+    result = defaultdict(list)
+    for dataset in iter_datasets(ldb_dir):
+        for i, version_id in dataset.numbered_versions().items():
+            version_path = get_hash_path(
+                Path(ds_version_dir),
+                version_id,
+            )
+            version_obj = DatasetVersion.parse(load_data_file(version_path))
+            result[version_obj.collection].append(
+                format_dataset_identifier(dataset.name, i),
+            )
+    for parent in os.listdir(collection_dir):
+        for filename in os.listdir(os.path.join(collection_dir, parent)):
+            result[  # pylint: disable=pointless-statement
+                f"{parent}{filename}"
+            ]
+    return dict(result)
+
+
 def get_dataset_version_hash(
     dataset: Dataset,
     dataset_version: Optional[int] = None,
